# pytket-stim

[Pytket](https://cqcl.github.io/pytket) is a Python module for interfacing
with CQC tket, a set of quantum programming tools.

[Stim](https://github.com/quantumlib/Stim) is a fast Clifford circuit simulator.

`pytket-stim` is an extension to `pytket` that allows `pytket` circuits to be
simulated using Stim.

## Getting started

`pytket-stim` is available for Python 3.7, 3.8 and 3.9, on Linux, MacOS and
Windows. To install, run:

```pip install pytket-stim```
